@@ -1,27 +1,25 @@
 # -*- coding: UTF-8 -*-
+#
+# Copyright © 2003 - 2015 Michal Čihař <michal@cihar.com>
+#
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
 # vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 SMS export code.
 '''
-__author__ = 'Michal Čihař'
-__email__ = 'michal@cihar.com'
-__license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License version 2 as published by
-the Free Software Foundation.
-
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-more details.
-
-You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-'''
 
 import os
 import imaplib
@@ -29,6 +27,8 @@ import wx
 import Wammu.MailWriter
 import Wammu.IMAP
 import re
+from Wammu.Locales import ugettext as _
+
 
 MAILBOX_RE = re.compile(r'\((?P<flags>(\s*\\\w*)*)\)\s+(?P<delim>[^ ]*)\s+(?P<name>.*)')
 POSSIBLY_QUOTED_RE = re.compile(r'"?([^"]*)"?')
@@ -69,22 +69,34 @@ def SMSToMailbox(parent, messages, contacts):
         f.close()
     except IOError:
         del parent.progress
-        wx.MessageDialog(parent,
+        wx.MessageDialog(
+            parent,
             _('Creating of file %s failed, bailing out.') % path,
             _('Can not create file!'),
-            wx.OK | wx.ICON_ERROR).ShowModal()
+            wx.OK | wx.ICON_ERROR
+        ).ShowModal()
         del parent.progress
         parent.SetStatusText(_('Export terminated'))
         return
 
     parent.progress.Update(100)
     del parent.progress
-    parent.SetStatusText(_('%(count)d messages exported to "%(path)s" (%(type)s)') % {'count':count, 'path':path, 'type': _('mailbox')})
+    parent.SetStatusText(
+        _('%(count)d messages exported to "%(path)s" (%(type)s)') % {
+            'count': count,
+            'path': path,
+            'type': _('mailbox')
+        }
+    )
 
 def SMSToMaildir(parent, messages, contacts):
     count = len(messages)
-    dlg = wx.DirDialog(parent, _('Select maildir directory where to save files'), os.getcwd(),
-              style=wx.DD_DEFAULT_STYLE|wx.DD_NEW_DIR_BUTTON)
+    dlg = wx.DirDialog(
+        parent,
+        _('Select maildir directory where to save files'),
+        os.getcwd(),
+        style=wx.DD_DEFAULT_STYLE | wx.DD_NEW_DIR_BUTTON
+    )
 
     if dlg.ShowModal() != wx.ID_OK:
         return
@@ -93,10 +105,12 @@ def SMSToMaildir(parent, messages, contacts):
     outpath = path
 
     if not os.path.isdir(os.path.join(outpath, 'new')):
-        res = wx.MessageDialog(parent,
+        res = wx.MessageDialog(
+            parent,
             _('Selected folder does not contain new subfolder and thus probably is not valid maildir.\n\nDo you want to create new subfolder and export to it?'),
             _('Folder doesn\'t look like maildir!'),
-            wx.YES_NO | wx.YES_DEFAULT | wx.CANCEL | wx.ICON_WARNING).ShowModal()
+            wx.YES_NO | wx.YES_DEFAULT | wx.CANCEL | wx.ICON_WARNING
+        ).ShowModal()
 
         if res == wx.ID_CANCEL:
             return
@@ -106,10 +120,12 @@ def SMSToMaildir(parent, messages, contacts):
             try:
                 os.mkdir(outpath)
             except OSError:
-                wx.MessageDialog(parent,
+                wx.MessageDialog(
+                    parent,
                     _('Creating of folder failed, bailing out.'),
                     _('Can not create folder!'),
-                    wx.OK | wx.ICON_ERROR).ShowModal()
+                    wx.OK | wx.ICON_ERROR
+                ).ShowModal()
                 return
     else:
         outpath = os.path.join(outpath, 'new')
@@ -126,10 +142,12 @@ def SMSToMaildir(parent, messages, contacts):
 
         outfile = os.path.join(outpath, filename)
         if os.path.exists(outfile):
-            res = wx.MessageDialog(parent,
+            res = wx.MessageDialog(
+                parent,
                 _('Output file already exists, this usually means that this message was already saved there.\n\nDo you wish to overwrite file %s?') % outfile,
                 _('File already exists!'),
-                wx.YES_NO | wx.NO_DEFAULT | wx.CANCEL | wx.ICON_WARNING).ShowModal()
+                wx.YES_NO | wx.NO_DEFAULT | wx.CANCEL | wx.ICON_WARNING
+            ).ShowModal()
 
             if res == wx.ID_CANCEL:
                 del parent.progress
@@ -143,10 +161,12 @@ def SMSToMaildir(parent, messages, contacts):
             f.write(data)
             f.close()
         except IOError:
-            wx.MessageDialog(parent,
+            wx.MessageDialog(
+                parent,
                 _('Creating of file %s failed, bailing out.') % outfile,
                 _('Can not create file!'),
-                wx.OK | wx.ICON_ERROR).ShowModal()
+                wx.OK | wx.ICON_ERROR
+            ).ShowModal()
             del parent.progress
             parent.SetStatusText(_('Export terminated'))
             return
@@ -154,7 +174,13 @@ def SMSToMaildir(parent, messages, contacts):
     parent.progress.Update(100)
     del parent.progress
 
-    parent.SetStatusText(_('%(count)d messages exported to "%(path)s" (%(type)s)') % {'count':count, 'path':path, 'type': _('maildir')})
+    parent.SetStatusText(
+        _('%(count)d messages exported to "%(path)s" (%(type)s)') % {
+            'count': count,
+            'path': path,
+            'type': _('maildir')
+        }
+    )
 
 def ParseIMAPFolder(item):
     '''
@@ -193,10 +219,13 @@ def SMSToIMAP(parent, messages, contacts):
         if res[0] == 'OK':
             break
         else:
-            if wx.MessageDialog(parent,
+            dialog = wx.MessageDialog(
+                parent,
                 _('Can not login, you probably entered invalid login information. Do you want to retry?'),
                 _('Login failed!'),
-                wx.YES_NO | wx.YES_DEFAULT | wx.ICON_ERROR).ShowModal() == wx.ID_NO:
+                wx.YES_NO | wx.YES_DEFAULT | wx.ICON_ERROR
+            )
+            if dialog.ShowModal() == wx.ID_NO:
                 return
 
     busy = wx.BusyInfo(_('Listing folders on IMAP server...'))
@@ -206,10 +235,12 @@ def SMSToIMAP(parent, messages, contacts):
         res = 'FAIL'
     del busy
     if res != 'OK':
-        wx.MessageDialog(parent,
+        wx.MessageDialog(
+            parent,
             _('Can not list folders on server, bailing out.'),
             _('Listing failed!'),
-            wx.OK | wx.ICON_ERROR).ShowModal()
+            wx.OK | wx.ICON_ERROR
+        ).ShowModal()
         parent.SetStatusText(_('Export terminated'))
         return
 
@@ -239,10 +270,12 @@ def SMSToIMAP(parent, messages, contacts):
         except:
             pass
 
-    dlg = wx.SingleChoiceDialog(parent,
+    dlg = wx.SingleChoiceDialog(
+        parent,
         _('Please select folder on server %s where messages will be stored') % imapConfig.server,
         _('Select folder'),
-        folders, wx.CHOICEDLG_STYLE | wx.RESIZE_BORDER)
+        folders, wx.CHOICEDLG_STYLE | wx.RESIZE_BORDER
+    )
     if folderIndex > 0:
         dlg.SetSelection(folderIndex)
     if dlg.ShowModal() == wx.ID_CANCEL:
@@ -263,19 +296,22 @@ def SMSToIMAP(parent, messages, contacts):
         res = ['FAIL']
     del busy
     if res[0] != 'OK':
-        wx.MessageDialog(parent,
+        wx.MessageDialog(
+            parent,
             _('Can not select folder %s on server, bailing out.') % folder,
             _('Selecting failed!'),
-            wx.OK | wx.ICON_ERROR).ShowModal()
+            wx.OK | wx.ICON_ERROR
+        ).ShowModal()
         parent.SetStatusText(_('Export terminated'))
         return
 
     def msgFilter(sms):
-        return \
-               (imapConfig.backupRead   and sms['SMS'][0]['State'] == 'Read') \
-            or (imapConfig.backupSent   and sms['SMS'][0]['State'] == 'Sent') \
-            or (imapConfig.backupUnread and sms['SMS'][0]['State'] == 'UnRead') \
-            or (imapConfig.backupUnsent and sms['SMS'][0]['State'] == 'UnSent')
+        return (
+            (imapConfig.backupRead and sms['SMS'][0]['State'] == 'Read') or
+            (imapConfig.backupSent and sms['SMS'][0]['State'] == 'Sent') or
+            (imapConfig.backupUnread and sms['SMS'][0]['State'] == 'UnRead')or
+            (imapConfig.backupUnsent and sms['SMS'][0]['State'] == 'UnSent')
+        )
 
     messages = filter(msgFilter, messages)
     count = len(messages)
@@ -294,7 +330,7 @@ def SMSToIMAP(parent, messages, contacts):
 
         filename, data, msgid = Wammu.MailWriter.SMSToMail(parent.cfg, sms, contacts)
 
-        if imapConfig.newMessages == True:
+        if imapConfig.newMessages:
             res, msgnums = m.search(None, 'HEADER', '"Message-ID" "' + msgid + '"')
             if len(msgnums[0].split()) != 0:
                 continue
@@ -306,10 +342,12 @@ def SMSToIMAP(parent, messages, contacts):
         except:
             res = ['FAIL']
         if res[0] != 'OK':
-            wx.MessageDialog(parent,
+            wx.MessageDialog(
+                parent,
                 _('Can not save message to folder %s on server, bailing out.') % folder,
                 _('Saving failed!'),
-                wx.OK | wx.ICON_ERROR).ShowModal()
+                wx.OK | wx.ICON_ERROR
+            ).ShowModal()
             parent.progress.Update(100)
             del parent.progress
             parent.SetStatusText(_('Export terminated'))
@@ -323,15 +361,33 @@ def SMSToIMAP(parent, messages, contacts):
     except:
         pass
 
-    if imapConfig.newMessages == False:
-        parent.SetStatusText(_('%(count)d messages exported to "%(path)s" (%(type)s)') % {'count':count, 'path':path, 'type': _('IMAP server')})
+    if not imapConfig.newMessages:
+        parent.SetStatusText(
+            _('%(count)d messages exported to "%(path)s" (%(type)s)') % {
+                'count': count,
+                'path': path,
+                'type': _('IMAP server')
+            }
+        )
     else:
-        parent.SetStatusText(_('%(new)d new of %(count)d messages exported to "%(path)s" (%(type)s)') % {'new':new_messages_num, 'count':count, 'path':path, 'type': _('IMAP server')})
+        parent.SetStatusText(
+            _('%(new)d new of %(count)d messages exported to "%(path)s" (%(type)s)') % {
+                'new': new_messages_num,
+                'count': count,
+                'path': path,
+                'type': _('IMAP server')
+            }
+        )
 
 def SMSExport(parent, messages, contacts):
     # Select where to export
-    dlg = wx.SingleChoiceDialog(parent, _('Where do you want to export emails created from your messages?'), _('Select export type'),
-                                [_('Mailbox file'), _('Maildir folder'), _('IMAP account')], wx.CHOICEDLG_STYLE | wx.RESIZE_BORDER)
+    dlg = wx.SingleChoiceDialog(
+        parent,
+        _('Where do you want to export emails created from your messages?'),
+        _('Select export type'),
+        [_('Mailbox file'), _('Maildir folder'), _('IMAP account')],
+        wx.CHOICEDLG_STYLE | wx.RESIZE_BORDER
+    )
     if dlg.ShowModal() != wx.ID_OK:
         return
 
@@ -419,7 +475,7 @@ class IMAPConfigHelper:
 
 class IMAPSettingsDialog(wx.Dialog):
     def __init__(self, parent, imapConfig):
-        wx.Dialog.__init__(self, parent, -1, _("IMAP Settings"), style = wx.DEFAULT_DIALOG_STYLE | wx.RESIZE_BORDER)
+        wx.Dialog.__init__(self, parent, -1, _("IMAP Settings"), style=wx.DEFAULT_DIALOG_STYLE | wx.RESIZE_BORDER)
         self.cfg = imapConfig
         self.connectionFrameSizer_staticbox = wx.StaticBox(self, -1, _("Connection Details"))
         self.preferenciesFrameSizer_staticbox = wx.StaticBox(self, -1, _("Preferences"))
@@ -504,7 +560,7 @@ class IMAPSettingsDialog(wx.Dialog):
         connectionGridSizer.Add(self.passwordTextCtrl, 0, wx.EXPAND, 0)
         connectionGridSizer.AddGrowableCol(1)
         connectionFrameSizer.Add(connectionGridSizer, 1, wx.EXPAND, 0)
-        mainSizer.Add(connectionFrameSizer, 0, wx.ALL|wx.EXPAND, 2)
+        mainSizer.Add(connectionFrameSizer, 0, wx.ALL | wx.EXPAND, 2)
         preferenciesGridSizer.Add((90, 20), 0, 0, 0)
         preferenciesGridSizer.Add(self.rememberCheckBox, 0, 0, 0)
         preferenciesGridSizer.Add((20, 20), 0, 0, 0)
@@ -513,17 +569,17 @@ class IMAPSettingsDialog(wx.Dialog):
         preferenciesGridSizer.Add(self.newMessagesCheckBox, 0, 0, 0)
         preferenciesGridSizer.AddGrowableCol(1)
         preferenciesFrameSizer.Add(preferenciesGridSizer, 1, wx.EXPAND, 0)
-        mainSizer.Add(preferenciesFrameSizer, 0, wx.ALL|wx.EXPAND, 2)
+        mainSizer.Add(preferenciesFrameSizer, 0, wx.ALL | wx.EXPAND, 2)
         stateFrameSizer.Add(self.readCheckBox, 1, wx.EXPAND, 0)
         stateFrameSizer.Add(self.sentCheckBox, 1, wx.EXPAND, 0)
         stateFrameSizer.Add(self.unreadCheckBox, 1, wx.EXPAND, 0)
         stateFrameSizer.Add(self.unsentCheckBox, 1, wx.EXPAND, 0)
-        mainSizer.Add(stateFrameSizer, 0, wx.ALL|wx.EXPAND, 2)
+        mainSizer.Add(stateFrameSizer, 0, wx.ALL | wx.EXPAND, 2)
         buttonRowSizer.Add((20, 20), 1, wx.EXPAND, 0)
         buttonRowSizer.Add(self.applyButton, 0, wx.ALIGN_BOTTOM, 0)
         buttonRowSizer.Add(self.cancelButton, 0, wx.ALIGN_BOTTOM, 0)
         buttonRowSizer.Add(self.okButton, 0, wx.ALIGN_BOTTOM, 0)
-        mainSizer.Add(buttonRowSizer, 1, wx.ALL|wx.EXPAND, 2)
+        mainSizer.Add(buttonRowSizer, 1, wx.ALL | wx.EXPAND, 2)
         self.SetSizer(mainSizer)
         mainSizer.Fit(self)
         self.Layout()
@@ -551,7 +607,7 @@ class IMAPSettingsDialog(wx.Dialog):
         if self.serverTextCtrl.GetValue() == "":
             counter += 1
             error += _('%d. Server incomplete\n') % counter
-        if self.portTextCtrl.GetValue() == "" or re.search('\D', self.portTextCtrl.GetValue()) :
+        if self.portTextCtrl.GetValue() == "" or re.search('\D', self.portTextCtrl.GetValue()):
             counter += 1
             error += _('%d. Port invalid\n') % counter
         if self.loginTextCtrl.GetValue() == "":
@@ -560,18 +616,20 @@ class IMAPSettingsDialog(wx.Dialog):
         if self.passwordTextCtrl.GetValue() == "":
             counter += 1
             error += _('%d. Password incomplete\n') % counter
-        if  not self.readCheckBox.GetValue() and \
-            not self.sentCheckBox.GetValue() and \
-            not self.unreadCheckBox.GetValue() and \
-            not self.unsentCheckBox.GetValue():
+        if  (not self.readCheckBox.GetValue() and
+                not self.sentCheckBox.GetValue() and
+                not self.unreadCheckBox.GetValue() and
+                not self.unsentCheckBox.GetValue()):
             counter += 1
             error += _('%d. No messages to back-up selected. Please tick at least one of the states.') % counter
 
         if counter != 0:
-            wx.MessageDialog(self,
+            wx.MessageDialog(
+                self,
                 error,
                 _('Incomplete'),
-                wx.OK | wx.ICON_ERROR).ShowModal()
+                wx.OK | wx.ICON_ERROR
+            ).ShowModal()
         else:
             self.__copy_config()
             event.Skip()
